package Sah::Schema::negeven;

our $DATE = '2016-07-18'; # DATE
our $VERSION = '0.05'; # VERSION

our $schema = ['negint', {
    summary => 'Negative even number',
    div_by => 2,
}, {}];

1;
# ABSTRACT: Negative even number

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schema::negeven - Negative even number

=head1 VERSION

This document describes version 0.05 of Sah::Schema::negeven (from Perl distribution Sah-Schemas-Int), released on 2016-07-18.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Int>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Sah-Schema-Int>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Int>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
